//
//  View.swift
//  StarWars
//
//  Created by Mark Meretzky on 11/20/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class View: UIView {
	let imageView: UIImageView = UIImageView(image: UIImage(named: "Star_Wars_Logo.png"));

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);
		backgroundColor = UIColor.blackColor();
		addSubview(imageView);
		
		//Center the imageView in this View.
		imageView.center = center;

		//Keep the imageView centered in this View,
		//even when the dimensions of this View change.
		imageView.autoresizingMask =
			UIViewAutoresizing.FlexibleLeftMargin
			| UIViewAutoresizing.FlexibleRightMargin
			| UIViewAutoresizing.FlexibleTopMargin
			| UIViewAutoresizing.FlexibleBottomMargin;
	}

	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.

	//The fade-in starts when the zoom starts, and the fade-out ends when the zoom ends.
	//In other words, the image is already zooming away from us as it fades in,
	//and it is still zooming away from us as it fades out.

	override func drawRect(rect: CGRect) {
		// Drawing code
		imageView.alpha = 0;
		imageView.transform = CGAffineTransformMakeScale(0.65, 0.65);

		let delay: NSTimeInterval = 22.75; //seconds until first animations begin
		let fadeDuration: NSTimeInterval = 0.25;
		let zoomDuration: NSTimeInterval = 8;

		//The fading animations.
		UIView.animateWithDuration(fadeDuration,
			delay: delay,
			options:  UIViewAnimationOptions.CurveLinear,
			animations: {
				//Fade in the imageView suddenly.
				self.imageView.alpha = 1;
			},
			completion: {(b: Bool) in
				UIView.animateWithDuration(fadeDuration,
					delay: zoomDuration - 2 * fadeDuration,
					options:  UIViewAnimationOptions.CurveLinear,
					animations: {
						//Fade out the imageView suddenly.
						self.imageView.alpha = 0;
					},
					completion: nil
				);
			}
		);

		//The zooming animation.
		UIView.animateWithDuration(zoomDuration,
			delay: delay,
			options:  UIViewAnimationOptions.CurveEaseOut,
			animations: {
				//Shrink the imageView: zoom it away from the user.
				self.imageView.transform = CGAffineTransformMakeScale(0.01, 0.01);
			},
			completion: nil
		);
	}

}
